@@ -50,7 +50,7 @@ from wavepy2.util.common import common_tools
 from wavepy2.util.ini.initializer import get_registered_ini_instance
 from wavepy2.util.log.logger import get_registered_logger_instance
 from wavepy2.util.plot import plot_tools
-from wavepy2.util.plot.plotter import WavePyInteractiveWidget
+from wavepy2.util.plot.plotter import WavePyInteractiveWidget, WavePyWidget
 from wavepy2.util.io.read_write_file import read_tiff
 
 from wavepy2.tools.common.wavepy_data import WavePyData
@@ -148,22 +148,23 @@ def generate_initialization_parameters_sgt(img_file_name,
                       remove_2nd_order=remove_2nd_order,
                       material_idx=material_idx)
 
-class SGTInputParametersWidget(WavePyInteractiveWidget):
+
+
+class AbstractSGTInputParametersWidget():
     WIDTH  = 800
     HEIGHT = 430
 
-    def __init__(self, parent):
-        super(SGTInputParametersWidget, self).__init__(parent, message="Input Parameters", title="Input Parameters")
-        self.__ini     = get_registered_ini_instance()
-        self.__logger  = get_registered_logger_instance()
+    def __init__(self, application_name=None):
+        self.__ini     = get_registered_ini_instance(application_name=application_name)
+        self.__logger  = get_registered_logger_instance(application_name=application_name)
 
         self.img                = self.__ini.get_string_from_ini("Files", "sample")
         self.imgRef             = self.__ini.get_string_from_ini("Files", "reference")
         self.imgBlank           = self.__ini.get_string_from_ini("Files", "blank")
-        self.mode               = MODES.index(self.__ini.get_string_from_ini("Parameters", "Mode", default="Relative"))
+        self.mode               = MODES.index(self.__ini.get_string_from_ini("Parameters", "Mode", default=MODES[0]))
         self.pixel              = self.__ini.get_float_from_ini("Parameters", "pixel size", default=6.5e-07)
         self.gratingPeriod      = self.__ini.get_float_from_ini("Parameters", "checkerboard grating period", default=4.8e-06)
-        self.pattern            = PATTERNS.index(self.__ini.get_string_from_ini("Parameters", "pattern", default="Diagonal half pi"))
+        self.pattern            = PATTERNS.index(self.__ini.get_string_from_ini("Parameters", "pattern", default=PATTERNS[0]))
         self.distDet2sample     = self.__ini.get_float_from_ini("Parameters", "distance detector to gr", default=0.33)
         self.phenergy           = self.__ini.get_float_from_ini("Parameters", "photon energy", default=14000.0)
         self.sourceDistance     = self.__ini.get_float_from_ini("Parameters", "source distance", default=32.0)
@@ -177,24 +178,28 @@ class SGTInputParametersWidget(WavePyInteractiveWidget):
         self.remove_2nd_order   = self.__ini.get_boolean_from_ini("Runtime", "remove 2nd order", default=False)
         self.material_idx       = self.__ini.get_int_from_ini("Runtime", "material idx", default=0)
 
-
     def build_widget(self, **kwargs):
-        self.setFixedWidth(self.WIDTH)
-        self.setFixedHeight(self.HEIGHT)
+        try: show_runtime_options = kwargs["show_runtime_options"]
+        except: show_runtime_options = True
 
-        tabs = plot_tools.tabWidget(self.get_central_widget())
+        try:    widget_width = kwargs["widget_width"]
+        except: widget_width = self.WIDTH
+        try:    widget_height = kwargs["widget_height"]
+        except: widget_height = self.HEIGHT
+
+        self.setFixedWidth(widget_width)
+        self.setFixedHeight(widget_height)
+
+        if show_runtime_options: tabs = plot_tools.tabWidget(self.get_central_widget())
 
         ini_widget = QWidget()
-        ini_widget.setFixedHeight(self.HEIGHT-10)
-        ini_widget.setFixedWidth(self.WIDTH-10)
-        runtime_widget = QWidget()
-        runtime_widget.setFixedHeight(self.HEIGHT-10)
-        runtime_widget.setFixedWidth(self.WIDTH-10)
+        ini_widget.setFixedHeight(widget_height-10)
+        ini_widget.setFixedWidth(widget_width-10)
 
-        plot_tools.createTabPage(tabs, "Initialization Parameter", widgetToAdd=ini_widget)
-        plot_tools.createTabPage(tabs, "Runtime Parameter", widgetToAdd=runtime_widget)
+        if show_runtime_options: plot_tools.createTabPage(tabs, "Initialization Parameter", widgetToAdd=ini_widget)
+        else: self.get_central_widget().layout().addWidget(ini_widget)
 
-        main_box = plot_tools.widgetBox(ini_widget, "", width=self.WIDTH-70, height=self.HEIGHT-50)
+        main_box = plot_tools.widgetBox(ini_widget, "", width=widget_width-70, height=widget_height-50)
 
         plot_tools.comboBox(main_box, self, "mode", label="Mode", items=MODES, callback=self.set_mode, orientation="horizontal")
 
@@ -222,16 +227,24 @@ class SGTInputParametersWidget(WavePyInteractiveWidget):
         plot_tools.lineEdit(main_box, self, "sourceDistance", label="Source Distance", labelWidth=250, valueType=float, orientation="horizontal")
 
         #--------------------------------------------------
-        main_box = plot_tools.widgetBox(runtime_widget, "", width=self.WIDTH-70, height=self.HEIGHT-50)
 
-        plot_tools.checkBox(main_box, self, "correct_pi_jump", "Correct pi jump in DPC signal")
-        plot_tools.checkBox(main_box, self, "remove_mean", "Remove mean DPC")
-        plot_tools.checkBox(main_box, self, "correct_dpc_center", "Correct DPC center")
-        plot_tools.checkBox(main_box, self, "remove_linear", "Remove 2D linear fit from DPC")
-        plot_tools.checkBox(main_box, self, "do_integration", "Calculate Frankot-Chellappa integration")
-        plot_tools.checkBox(main_box, self, "calc_thickness", "Convert phase to thickness")
-        plot_tools.checkBox(main_box, self, "remove_2nd_order", "Remove 2nd order polynomial from integrated Phase")
-        plot_tools.comboBox(main_box, self, "material_idx", items=["Diamond", "Beryllium"], label="Material", labelWidth=200, orientation="horizontal")
+        if show_runtime_options:
+            runtime_widget = QWidget()
+            runtime_widget.setFixedHeight(widget_height-10)
+            runtime_widget.setFixedWidth(widget_width-10)
+
+            plot_tools.createTabPage(tabs, "Runtime Parameter", widgetToAdd=runtime_widget)
+
+            main_box = plot_tools.widgetBox(runtime_widget, "", width=widget_width-70, height=widget_height-50)
+
+            plot_tools.checkBox(main_box, self, "correct_pi_jump", "Correct pi jump in DPC signal")
+            plot_tools.checkBox(main_box, self, "remove_mean", "Remove mean DPC")
+            plot_tools.checkBox(main_box, self, "correct_dpc_center", "Correct DPC center")
+            plot_tools.checkBox(main_box, self, "remove_linear", "Remove 2D linear fit from DPC")
+            plot_tools.checkBox(main_box, self, "do_integration", "Calculate Frankot-Chellappa integration")
+            plot_tools.checkBox(main_box, self, "calc_thickness", "Convert phase to thickness")
+            plot_tools.checkBox(main_box, self, "remove_2nd_order", "Remove 2nd order polynomial from integrated Phase")
+            plot_tools.comboBox(main_box, self, "material_idx", items=["Diamond", "Beryllium"], label="Material", labelWidth=200, orientation="horizontal")
 
         self.update()
 
@@ -292,3 +305,34 @@ class SGTInputParametersWidget(WavePyInteractiveWidget):
     def get_rejected_output(self):
         self.__logger.print_error("Initialization Canceled, Program exit")
         sys.exit(1)
+
+from PyQt5.QtWidgets import QVBoxLayout, QHBoxLayout
+from PyQt5.QtCore import Qt
+
+class SGTInputParametersWidget(AbstractSGTInputParametersWidget, WavePyWidget):
+    def __init__(self, application_name=None, **kwargs):
+        AbstractSGTInputParametersWidget.__init__(self, application_name)
+        WavePyWidget.__init__(self, parent=None, application_name=application_name)
+
+        layout = QHBoxLayout()
+        layout.setAlignment(Qt.AlignCenter)
+        self.setLayout(layout)
+
+        self.__central_widget = QWidget()
+        self.__central_widget.setLayout(QVBoxLayout())
+
+        layout.addWidget(self.__central_widget)
+
+    def get_central_widget(self):
+        return self.__central_widget
+
+    def get_plot_tab_name(self):
+        return "Single Grating Talbot Initialization Parameters"
+
+    def allows_saving(self):
+        return False
+
+class SGTInputParametersDialog(AbstractSGTInputParametersWidget, WavePyInteractiveWidget):
+    def __init__(self, parent, application_name=None, **kwargs):
+        AbstractSGTInputParametersWidget.__init__(self, application_name)
+        WavePyInteractiveWidget.__init__(self, parent, message="Input Parameters", title="Input Parameters")
